pygeoip.timezone

Package pygeoip :: Module timezone |
[frames] | no frames]

# Module timezone

source code

Time zone data and lookup function

Authors:
  Jennifer Ennis <zaylea@gmail.com>, William Tisäter <william@defunct.cc>

License: Copyright(C) 2004 MaxMind LLC

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program. If not, see <http://www.gnu.org/licenses/lgpl.txt>.

Functions
str |
time_zone_by_country_and_region(country_code, region_code=None) Get time zone from country code and region code. | source code

Variables
| country_dict = ``{``'``AD``'``:` `'``Europe/Andorra``'``,` `'``AE``'``:` `'``Asia/Dubai``'``,` `'``A``...``
| __package__ = `None`

Function Details

### time_zone_by_country_and_region(country_code, region_code=None) | source code
Get time zone from country code and region code. Parameters: `country_code` (str) - Country code `region_code` (str) - Region code Returns: str Time zone

Variables Details

  ### country_dict Value:
      {'AD': 'Europe/Andorra',
       'AE': 'Asia/Dubai',
       'AF': 'Asia/Kabul',
       'AG': 'America/Antigua',
       'AI': 'America/Anguilla',
       'AL': 'Europe/Tirane',
       'AM': 'Asia/Yerevan',
       'AN': 'America/Curacao',
      ...